//  //
//  ###  ##### #   #               -= Confix Library =-                  //
// #   # #     ## ## Confix.cpp - Main include header                    //
// #     ####   ###                                                      //
// #     #      ###  Main confix header to be included by applications   //
// #   # #     ## ## making use of confix                                //
//  ###  #     #   # R1             (C)2002 Markus Ewald -> License.txt  //
//  //
#include "Confix/Confix.h"

/** @mainpage Confix documentation

    @section About About Confix
      @subsection Intro Introduction
        Confix is a configuration file parser designed to be bullet proof
        regardless what data you feed it with. The configuration file contents
        are exposed using a simple object model which allows you to easily
        manipulate, add or remove variables.

        It can handle most configuration file formats, including multi-line
        strings with escape sequences and hexadecimal numbers. Modifying the
        configuration file does not destroy its formatting.

      @subsection Features Features
        General
          - Does not reformat the file on saving
          - Bullet proof parser
          - Clean and intuitive object model
          - Freeware

        File format
          - Parses multi-line strings with support for escape sequences
          - Reads hexadecimal numbers (0x220) and character constants ('a')
          - Able to manage multiple variables with the same name
          - Allows to read, change variables as well as to add and remove them
          - Recognizes common comment types: "#", ";" and "//"
          - Supports sections to categorize variables
          - Handles Hard (lf) and soft returns (crlf)
         
        Unsupported:
          - Free quotes inside quoted strings (eg. test = "abc "foo" xyz")
          - String continuation using backslash-newline (eg. test = this is a \\<nl>single variable)
          - Assignations without equals sign (eg. test 123)

      @subsection Copy Copyright
        Confix was written by Markus Ewald @ LunaticSystems.
        The author can be contacted via confix@spam.lunaticsystems.de (remove the 'spam.')

        Confix is freely distributable. You are free to use it in your
        own applications, freeware and commercial ones in any form, without
        the requirement of making the source to your application public.

        See License.txt for further informations.

    @section Usage Usage
      @subsection Integration Integration into applications
        The headers required to use Confix in another application are contained
        in the 'include' subdirectory of confix. Inside this directory, you'll find
        other directory named 'confix'. Do not add '<confix_path>/include/confix'
        to your include search paths, but add '<confix_path>/include'.

        Add these either in the global options
        (Menu "Extras" -> Item "Options" -> Tab "Directories" ->
         Show directories for "Include files")
        or in the local project settings
        (Menu "Project" -> Item "Settings" -> Tab "C/C++" ->
         Category "Preprocessor" -> TextBox "Additional Include Directories"

        In consequence, you have to #include confix into your files like this:
        @code #include "confix/confix.h" @endcode

        My justification for this scheme:
        - Overlookable configuration: No more masses of include paths for
          per-project includes, only one general include folder per project.
        - Solves ambiguities: In your project, when you include headers from
          external libraries, you have to explicitely specify from which library
          folder to include.

        Of course, you also have to link your project against the apropriate
        library (<confix_path>/lib/confix/confix.lib for VisualC++ 6.0 / 7.0
*/

#if defined(__WIN32__) && defined(CONFIX_DLL)
#define WIN32_LEAN_AND_MEAN
#include <windows.h>

// ####################################################################### //
// # DllMain()                                                           # // 
// ####################################################################### //
/** Dll main entry point

    @param  hModule             Dll instance module handle
    @param  ul_reason_for_call  Call reason message
    @param  lpReserved          Reserved
*/
BOOL APIENTRY DllMain(HANDLE hModule, 
                      DWORD  ul_reason_for_call, 
                      LPVOID lpReserved) {
  switch (ul_reason_for_call) {
    case DLL_PROCESS_ATTACH:
    case DLL_THREAD_ATTACH:
    case DLL_THREAD_DETACH:
    case DLL_PROCESS_DETACH:
      break;
  }
 
  return TRUE;
}

#endif
